# Generated by Django 4.2.3 on 2023-07-30 18:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    replaces = [('ocr_translate', '0002_ocrboxmodel_default_options_ocrmodel_default_options_and_more'), ('ocr_translate', '0003_language_default_options'), ('ocr_translate', '0004_remove_language_break_chars_and_more'), ('ocr_translate', '0005_alter_ocrboxmodel_default_options_and_more')]

    dependencies = [
        ('ocr_translate', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='language',
            name='default_options',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='lang_default_options', to='ocr_translate.optiondict'),
        ),
        migrations.RemoveField(
            model_name='language',
            name='break_chars',
        ),
        migrations.RemoveField(
            model_name='language',
            name='ignore_chars',
        ),
        migrations.AddField(
            model_name='ocrboxmodel',
            name='default_options',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='box_default_options', to='ocr_translate.optiondict'),
        ),
        migrations.AddField(
            model_name='ocrmodel',
            name='default_options',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='ocr_default_options', to='ocr_translate.optiondict'),
        ),
        migrations.AddField(
            model_name='tslmodel',
            name='default_options',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='tsl_default_options', to='ocr_translate.optiondict'),
        ),
    ]
