# Generated by Django 4.2.4 on 2023-08-03 13:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ocr_translate', '0002_ocrboxmodel_default_options_ocrmodel_default_options_and_more_squashed_0005_alter_ocrboxmodel_default_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='tslmodel',
            name='entrypoint',
            field=models.CharField(max_length=128, null=True),
        ),
    ]
